@@ -1,11 +1,10 @@
-from distutils.log import error
 import functools
-from json import JSONDecodeError
 import json
+from json import JSONDecodeError
 from typing import Callable, Dict, List
-import loghelp
-from errors import ProgrammerError, ProgrammerErrorHandle, SafeCatchAll
-import errors
+from . import loghelp
+from . import errors
+from . errors import ProgrammerError, ProgrammerErrorHandle, SafeCatchAll
 
 
 class EventError(errors.Error):
